@@ -85,7 +85,7 @@ ImportWizard::~ImportWizard()
 
 void ImportWizard::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "FolderSelectionDialog");
+    KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("FolderSelectionDialog"));
     if (group.hasKey("LastSelectedFolder")) {
         mSelfilterpage->widget()->mCollectionRequestor->setCollection(CommonKernel->collectionFromId(group.readEntry("LastSelectedFolder", -1)));
     }
@@ -93,7 +93,7 @@ void ImportWizard::readConfig()
 
 void ImportWizard::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "FolderSelectionDialog");
+    KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("FolderSelectionDialog"));
     group.writeEntry("LastSelectedFolder", mSelfilterpage->widget()->mCollectionRequestor->collection().id());
     group.sync();
 }
@@ -191,7 +191,7 @@ void ImportWizard::createAutomaticModePage()
 
 void ImportWizard::initializeImportModule()
 {
-    const QVector<LibImportWizard::AbstractImporter *> lstPlugins = ImportMailPluginManager::self()->pluginsList();
+    const QList<LibImportWizard::AbstractImporter *> lstPlugins = ImportMailPluginManager::self()->pluginsList();
     for (LibImportWizard::AbstractImporter *abstractPlugin : lstPlugins) {
         if (abstractPlugin->foundMailer()) {
             abstractPlugin->setAbstractDisplayInfo(mAbstractDisplayInfo);
@@ -419,3 +419,5 @@ void ImportWizard::slotSelectManualSelectionChanged(bool b)
     mMode = b ? WizardMode::Manual : WizardMode::AutoDetect;
     updatePagesFromMode();
 }
+
+#include "moc_importwizard.cpp"
